#
# spec file for package python-llfuse
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-llfuse
Version:        0.40
Release:        2.1
Summary:        Python Bindings for the low-level FUSE API
License:        LGPL-2.1+
Group:          Development/Libraries/Python
Url:            http://code.google.com/p/python-llfuse/
Source:         http://python-llfuse.googlecode.com/files/llfuse-%{version}.tar.bz2
# PATCH-MISSING-TAG -- See http://wiki.opensuse.org/openSUSE:Packaging_Patches_guidelines
Patch1:         python-llfuse-disable_sphinx.patch
BuildRequires:  fuse-devel >= 2.8.0
BuildRequires:  libattr-devel
BuildRequires:  pkgconfig
BuildRequires:  python-devel
BuildRequires:  python-setuptools >= 0.6.12
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
LLFUSE is a set of Python bindings for the low level FUSE API. It requires at
least FUSE 2.8.0 and supports both Python 2.x and 3.x.

LLFUSE was originally part of S3QL, but has been factored out so that it can be
used by other projects as well.

%prep
%setup -q -n llfuse-%{version}
%patch1
rm doc/html/.buildinfo

%build
python setup.py build

%install
python setup.py install --prefix="%{_prefix}" --root=%{buildroot}

%files
%defattr(-,root,root)
%doc Changes.txt LICENSE doc/html
%{python_sitearch}

%changelog
* Sun Dec  8 2013 p.drouand@gmail.com
- Update to version 0.40
  * Re-raising an exception from a request handler now works
    correctly under Python 3. Problems were caused by a Cython bug,
    but llfuse now works around the issue.
  * File atime, ctime and mtime can now also be represented as
    nanosecond integer values for increased resolution.
  * Python-llfuse no longer includes the setuptools/distribute
    bootstrap script. This module thus has to be installed manually
    if not already present on the system.
  * Duck-typing of the Operations instance is now supported.
  * Python-llfuse no longer requires a re-compilation of the
    Cython code (setup.py build_cython step) when compiling for MacOS
    or FreeBSD.
  * Extended attributes are now properly supported under FreeBSD.
- General spec file clean-up
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Sun Dec 11 2011 chris@computersalat.de
- update to 0.37.1
  * Fixed a segfault-causing race condition in Lock.acquire() and
    Lock.yield().
- 2011-12-05, llfuse 0.37
  * Explicitly call fuse_chan_destroy() in llfuse.close(), so
    that the mountpoint becomes inaccessible right away, even
    while the process is still running.
  * Added get_ino_t_bytes() and get_off_t_bytes() that return
    the number of bytes used for representing inode numbers
    and file offsets.
  * The yield_() method of the global lock now takes an additional
  * count* argument that can be used to yield the lock more than
    once.
  * Changed implementation of global lock. The global lock is
    no longer a mutex, but a boolean variable protected by a mutex,
    and changes are tracked with a condition object. This allows
    lock.yield() to work properly: if there are other threads waiting
    for the lock, they are guaranteed to run. If there are no other
    threads waiting for the lock, execution of the active thread
    continues immediately.
    The previous implementation using sched_yield() was mostly
    broken: threads trying to acquire the global lock were calling
    pthread_mutex_lock, so they got removed from the kernels
    runqueue. However, calls to sched_yield() would just put the
    active thread into the expired runqueue, and calls to
    pthread_mutex_unlock apparently do not synchronously move the
    threads waiting for the lock back to a runqueue. Therefore, most
    of the time the active thread would be the only thread in any
    runqueue and thus continue to run.
  * The Operations.forget() method now receives a list of
    (inode, nlookup) tuples rather than just one such tuple.
  * invalidate_entry() and invalidate_inode() no longer work
    synchronously. Instead, the message is put in a queue and send by
    a background thread.
  * The acquire() method of the global lock now has an optional
  * timeout* parameter.
  * The create() request handler now receives the open flags
    as an additional parameter.
- for more info please see Changes.txt
* Fri May 13 2011 pascal.bleser@opensuse.org
- update to 0.31
* Fri Dec 31 2010 pascal.bleser@opensuse.org
- initial version (0.29.4)
